==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/fr/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'Confirmez la suppression du lot d\'objets',
  'bulk_delete_help'	=> 'Vérifiez les objets ci-dessous pour la suppression du lot. Une fois supprimés, ces objets peuvent être restaurés, mais ils ne seront plus associés avec les utilisateurs auxquels ils sont actuellement assignés.',
  'bulk_delete_warn'	=> 'Vous allez supprimer :asset_count objets.',
	'bulk_update'		=> 'Mise à jour en bloc d\'actifs',
	'bulk_update_help'	=> 'Ce formulaire vous permet de mettre à jour plusieurs actifs à la fois. Seulement remplir les champs que vous devez modifier. Tous les champs laissés vides resteront inchangés. ',
	'bulk_update_warn'	=> 'Vous êtes sur le point de modifier les propriétés de l\'actif :asset_count .',
    'checkedout_to'		=> 'Extrait vers',
    'checkout_date'		=> 'Date d\'attribution',
    'checkin_date'		=> 'Date de dissociation',
    'checkout_to'		=> 'Caisse à',
    'cost'				=> 'Coût d\'achat',
    'create'			=> 'Créer des actifs',
    'date'				=> 'Date d\'achat',
    'depreciation'	    => 'Dépréciation',
    'depreciates_on'	=> 'Amortit sur',
    'default_location'	=> 'Emplacement par défaut',
    'eol_date'			=> 'Date de fin de vie',
    'eol_rate'			=> 'Taux de EOL',
    'expected_checkin'  => 'Date de dissociation prévue',
    'expires'			=> 'Expire',
    'fully_depreciated'	=> 'Entièrement amortis',
    'help_checkout'		=> 'Si vous souhaitez attribuer cet actif immédiatement, sélectionnez "prêt à déployer" dans la liste ci-dessus. ',
    'mac_address'		=> 'Adresse MAC',
    'manufacturer'		=> 'Fabricant',
    'model'				=> 'Modèle',
    'months'			=> 'Mois',
    'name'				=> 'Nom de l\'actif',
    'notes'				=> 'Remarques',
    'order'				=> 'Numéro de Commande',
    'qr'				=> 'Code QR',
    'requestable'		=> 'Les utilisateurs peuvent demander à cet actif',
    'select_statustype'	=> 'Choisissez le type de statut',
    'serial'			=> 'Série ',
    'status'			=> 'Statut',
    'tag'				=> 'Numéro d\'inventaire',
    'update'			=> 'Mise à jour de l\'actif',
    'warranty'			=> 'Garantie',
		'warranty_expires'		=> 'Expiration de garantie',
    'years'				=> 'années',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/fr/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Confirmez la suppression du lot d\'objets',
  'bulk_delete_help'	=> 'Vérifiez les objets ci-dessous pour la suppression du lot. Une fois supprimés, ces objets peuvent être restaurés, mais ils ne seront plus associés avec les utilisateurs auxquels ils sont actuellement assignés.',
  'bulk_delete_warn'	=> 'Vous allez supprimer :asset_count objets.',
    'bulk_update'		=> 'Mise à jour en bloc d\'actifs',
    'bulk_update_help'	=> 'Ce formulaire vous permet de mettre à jour plusieurs actifs à la fois. Seulement remplir les champs que vous devez modifier. Tous les champs laissés vides resteront inchangés. ',
    'bulk_update_warn'	=> 'Vous êtes sur le point de modifier les propriétés de l\'actif :asset_count .',
    'checkedout_to'		=> 'Extrait vers',
    'checkout_date'		=> 'Date d\'attribution',
    'checkin_date'		=> 'Date de dissociation',
    'checkout_to'		=> 'Caisse à',
    'cost'				=> 'Coût d\'achat',
    'create'			=> 'Créer des actifs',
    'date'				=> 'Date d\'achat',
    'depreciation'	    => 'Dépréciation',
    'depreciates_on'	=> 'Amortit sur',
    'default_location'	=> 'Emplacement par défaut',
    'eol_date'			=> 'Date de fin de vie',
    'eol_rate'			=> 'Taux de EOL',
    'expected_checkin'  => 'Date de dissociation prévue',
    'expires'			=> 'Expire',
    'fully_depreciated'	=> 'Entièrement amortis',
    'help_checkout'		=> 'Si vous souhaitez attribuer cet actif immédiatement, sélectionnez "prêt à déployer" dans la liste ci-dessus. ',
    'mac_address'		=> 'Adresse MAC',
    'manufacturer'		=> 'Fabricant',
    'model'				=> 'Modèle',
    'months'			=> 'Mois',
    'name'				=> 'Nom de l\'actif',
    'notes'				=> 'Remarques',
    'order'				=> 'Numéro de Commande',
    'qr'				=> 'Code QR',
    'requestable'		=> 'Les utilisateurs peuvent demander à cet actif',
    'select_statustype'	=> 'Choisissez le type de statut',
    'serial'			=> 'Série ',
    'status'			=> 'Statut',
    'tag'				=> 'Numéro d\'inventaire',
    'update'			=> 'Mise à jour de l\'actif',
    'warranty'			=> 'Garantie',
        'warranty_expires'		=> 'Expiration de garantie',
    'years'				=> 'années',
    'asset_location' => 'Mettre à jour l\'emplacement de l\'actif',
    'asset_location_update_default_current' => 'Mettre à jour l\'emplacement par défaut ET l\'emplacement réel',
    'asset_location_update_default' => 'Mettre à jour uniquement l\'emplacement par défaut',
    'asset_not_deployable' => 'L\'actif n\'est pas déployable. L\'actif ne peut pas être affecté.',
    'asset_deployable' => 'L\'actif est déployable. L\'actif peut être affecté.',
    'processing_spinner' => 'Traitement en cours...',
];
